"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const fs = require("node:fs");
const default_fs_1 = require("../lib/fs/default-fs");
const path = require("node:path");
class CleanCore {
    constructor(fs, logger) {
        this.fs = fs;
        this.logger = logger;
    }
    async run(flags) {
        const location = flags.location ? path.resolve(flags.location) : path.resolve('.');
        this.logger.log('* Cleaning project directory');
        const defaultFs = new default_fs_1.default();
        for (const f of defaultFs.listDirectory(location)) {
            if (this.shouldClean(f)) {
                fs.unlinkSync(f);
                this.logger.log(`  - deleted ${f}`);
            }
        }
    }
    shouldClean(f) {
        return (f.endsWith('.jsonld') && !f.endsWith('.data.jsonld')) || f.endsWith('.input') || f.endsWith('.rego');
    }
}
exports.default = CleanCore;
CleanCore.description = 'cleans debug and model data';
CleanCore.examples = [
    '<%= config.bin %> <%= command.id %>',
    '<%= config.bin %> <%= command.id %> -l /development/my-ruleset-project',
];
CleanCore.flags = {
    location: core_1.Flags.string({ char: 'l', description: 'path where the project will be created' }),
};
CleanCore.args = [];
//# sourceMappingURL=clean.js.map