"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const validate_path_1 = require("../../lib/commands/validate-path");
const path = require("node:path");
const model_generator_1 = require("../../lib/commands/model-generator");
class ModelDumpCore {
    constructor(fs, logger) {
        this.fs = fs;
        this.logger = logger;
    }
    async run(args, flags) {
        const ruleName = args.ruleName;
        const exampleId = args.id;
        const location = flags.location ? path.resolve(flags.location) : path.resolve('.');
        if (flags.filter) {
            const filter = flags.filter;
            (0, validate_path_1.validateFilter)(filter);
        }
        const generator = new model_generator_1.default(this.fs, this.logger);
        await (flags.filter || (!ruleName && !exampleId) ? generator.dumpFiltered(location, flags.filter) : generator.dumpSingle(location, ruleName, exampleId));
    }
}
exports.default = ModelDumpCore;
ModelDumpCore.description = 'serializes the JSON-LD model for an example';
ModelDumpCore.examples = [
    '<%= config.bin %> <%= command.id %> my-rule-1 example1negative',
];
ModelDumpCore.flags = {
    location: core_1.Flags.string({ char: 'l', description: 'path where the project will be created' }),
    filter: core_1.Flags.string({ char: 'f', description: 'regex used to filter the examples that are going to be validated' }),
};
ModelDumpCore.args = [
    { name: 'ruleName', required: false, description: 'name of the rule where the example will be added' },
    { name: 'id', required: false, description: 'id of the example' },
];
//# sourceMappingURL=dump.js.map