"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const amf_lexical_index_1 = require("../../lib/model/inspect/amf-lexical-index");
const editor_1 = require("../../lib/model/inspect/editor");
const fs_utils_1 = require("../../lib/fs/fs-utils");
const spec_client_provider_1 = require("../../lib/spec/spec-client-provider");
const path = require("node:path");
const inquirer = require('inquirer');
class ModelInspectCore {
    constructor(fs, logger) {
        this.fs = fs;
        this.logger = logger;
    }
    async run(args, flags) {
        const name = args.ruleName;
        const location = flags.location ? path.resolve(flags.location) : path.resolve('.');
        const ruleDir = fs_utils_1.default.listRuleDirs(this.fs, this.logger, location).find(rd => rd.ruleName === name || rd.path.endsWith(name));
        if (!ruleDir) {
            this.logger.error(`Cannot find rule named ${name} at directory ${location}`);
        }
        const example = ruleDir.findExample(args.id);
        if (!example) {
            this.logger.error(`Cannot find example ${args.id} for rule ${args.ruleName}`);
        }
        const spectype = fs_utils_1.default.findSpecType(this.fs, example);
        if (spectype === spec_client_provider_1.default.Spec.JSONLD) {
            this.logger.error(`Cannot build API model for JSON-LD document at ${example}`);
        }
        const spectClient = spec_client_provider_1.default.buildClient(spectype, this.fs, ruleDir.directory);
        const resultSpec = await spectClient.parse(example);
        const lexicalIndex = new amf_lexical_index_1.AMFLexicalIndex(resultSpec);
        await lexicalIndex.initialize();
        const apiContent = this.fs.readFileSync(example).toString();
        inquirer.registerPrompt('editor', editor_1.EditorPrompt);
        inquirer.prompt({
            type: 'editor',
            name: 'editor',
            content: apiContent,
            index: lexicalIndex,
        });
    }
}
exports.default = ModelInspectCore;
ModelInspectCore.description = 'toggles an interactive editor that shows the semantic model for a given input file';
ModelInspectCore.examples = [
    '<%= config.bin %> <%= command.id %> my-rule1 example1negative',
    '<%= config.bin %> <%= command.id %> -f positive.*',
];
ModelInspectCore.flags = {
    location: core_1.Flags.string({ char: 'l', description: 'path where the project will be created' }),
};
ModelInspectCore.args = [
    { name: 'ruleName', required: true, description: 'name of the rule where the example will be added' },
    { name: 'id', required: true, description: 'id of the example' },
];
//# sourceMappingURL=inspect.js.map