"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const example_creator_1 = require("../../lib/commands/example-creator");
const fs_utils_1 = require("../../lib/fs/fs-utils");
class ExampleCore {
    constructor(fs, logger) {
        this.fs = fs;
        this.logger = logger;
    }
    async run(args, flags) {
        const ruleName = args.ruleName;
        const id = args.id;
        new example_creator_1.default(flags.location, flags.only, flags.format, ruleName, id, this.logger, this.fs).create();
    }
}
exports.default = ExampleCore;
ExampleCore.description = 'generates a new example for a rule';
ExampleCore.examples = [
    '<%= config.bin %> <%= command.id %> mandatory-tags ex1',
    '<%= config.bin %> <%= command.id %> mandatory-tags ex1 -f grpc',
    '<%= config.bin %> <%= command.id %> mandatory-tags ex1 -f graphql --only positive',
];
ExampleCore.flags = {
    format: core_1.Flags.string({ char: 'f', description: 'spec format for the example (oas, swagger, raml, asyncapi, graphql, grpc, gcl, project)', default: fs_utils_1.default.FORMATS.OAS }),
    location: core_1.Flags.string({ char: 'l', description: 'path where the project has been created', default: '.' }),
    only: core_1.Flags.string({ char: 'o', description: 'generate only positive|negative example' }),
};
ExampleCore.args = [
    { name: 'ruleName', required: true, description: 'name of the rule where the example will be added' },
    { name: 'id', required: true, description: 'id of the example' },
];
//# sourceMappingURL=example.js.map