"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const project_generator_1 = require("../../lib/commands/project-generator");
const fs_utils_1 = require("../../lib/fs/fs-utils");
const validate_path_1 = require("../../lib/commands/validate-path");
const path = require("node:path");
class IndexCore {
    constructor(fs, logger) {
        this.fs = fs;
        this.logger = logger;
    }
    async run(args, flags) {
        const name = args.name;
        const ruleNameProfile = flags.ruleFileName;
        const location = flags.location ? path.resolve(flags.location) : path.resolve('.');
        const defaultSpec = flags.defaultSpec;
        (0, validate_path_1.validatePath)(location);
        await new project_generator_1.default(name, location, this.logger, this.fs, defaultSpec, ruleNameProfile).generate();
    }
}
exports.default = IndexCore;
IndexCore.description = 'Generates a new ruleset project';
IndexCore.examples = [
    '<%= config.bin %> <%= command.id %>',
    '<%= config.bin %> <%= command.id %> -l /development/my-ruleset-project',
    '<%= config.bin %> <%= command.id %> -l /development/my-ruleset-project -s oas',
];
IndexCore.flags = {
    location: core_1.Flags.string({ char: 'l', description: 'path where the project will be created' }),
    defaultSpec: core_1.Flags.string({ char: 's', options: Object.values(fs_utils_1.default.FORMATS), description: 'default spec for examples at new rules creation' }),
    ruleFileName: core_1.Flags.string({ char: 'n', description: 'name of the profile file in each rule' }),
};
IndexCore.args = [
    { name: 'name', required: true, description: 'name of the ruleset' },
];
//# sourceMappingURL=index.js.map