"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const rule_creator_1 = require("../../lib/commands/rule-creator");
const validate_path_1 = require("../../lib/commands/validate-path");
const path = require("node:path");
class NewRuleCore {
    constructor(fs, logger) {
        this.fs = fs;
        this.logger = logger;
    }
    async run(args, flags) {
        var _a, _b;
        const ruleName = args.name;
        const location = flags.location ? path.resolve(flags.location) : path.resolve('.');
        const message = (_a = flags.message) !== null && _a !== void 0 ? _a : '';
        const severity = (_b = flags.severity) !== null && _b !== void 0 ? _b : 'violation';
        (0, validate_path_1.validatePath)(location);
        return new rule_creator_1.default(location, ruleName, severity, message, this.logger, this.fs).create();
    }
}
exports.default = NewRuleCore;
NewRuleCore.description = 'creates a new rule for the ruleset';
NewRuleCore.examples = [
    '<%= config.bin %> <%= command.id %> mandatory-tags',
    '<%= config.bin %> <%= command.id %> mandatory-tags -s warning -m "tags are mandatory"',
    '<%= config.bin %> <%= command.id %> mandatory-tags -l /development/my-ruleset-project',
];
NewRuleCore.flags = {
    severity: core_1.Flags.string({ char: 's', options: Object.values(['warning', 'violation', 'info']), description: 'severity level for the rule' }),
    message: core_1.Flags.string({ char: 'm', description: 'error message for the rule' }),
    location: core_1.Flags.string({ char: 'l', description: 'path where the project will be created' }),
};
NewRuleCore.args = [{ name: 'name', required: true, description: 'name of the rule' }];
//# sourceMappingURL=rule.js.map