"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const test_runner_1 = require("../lib/commands/test-runner");
const validate_1 = require("../lib/validate");
class TestCore {
    constructor(fs, logger) {
        this.fs = fs;
        this.logger = logger;
    }
    async run(flags) {
        var _a, _b, _c;
        const location = flags.location ? flags.location : '.';
        const filter = (_a = flags.filter) !== null && _a !== void 0 ? _a : '.*';
        const debug = (_b = flags.debug) !== null && _b !== void 0 ? _b : false;
        const skip = (_c = flags.skipLinting) !== null && _c !== void 0 ? _c : false;
        const runner = new test_runner_1.default(location, this.fs, debug, skip, filter, this.logger, true);
        const results = await runner.run();
        validate_1.default.singleton.terminate();
        const failedRules = this.getFailedTests(results);
        this.reportTestResult(failedRules);
    }
    getFailedTests(results) {
        return results.filter(report => report.diff.length > 0);
    }
    reportTestResult(failedRules) {
        if (failedRules.length > 0) {
            this.printFailedTestsReport(failedRules);
        }
        else {
            this.printSuccessfulTestReport();
        }
    }
    printSuccessfulTestReport() {
        this.logger.log('\u001B[0mAll examples validate');
    }
    printFailedTestsReport(failedRules) {
        this.logger.log('\n\u001B[31mFailed rule(s):\u001B[0m\n');
        this.logger.log(`\u001B[0m${failedRules.length} rule(s) failed:`);
        for (const failedRule of failedRules) {
            this.logger.log(`\u001B[31m\u2717 ${failedRule.location}\u001B[0m\n`);
        }
    }
}
exports.default = TestCore;
TestCore.description = 'Lints the rules syntax and tests all the rule examples';
TestCore.examples = [
    '<%= config.bin %> <%= command.id %>',
    '<%= config.bin %> <%= command.id %> -f positive.*',
    '<%= config.bin %> <%= command.id %> -f rule-34 --debug',
    '<%= config.bin %> <%= command.id %> --debug',
    '<%= config.bin %> <%= command.id %> --skipLinting',
    '<%= config.bin %> <%= command.id %> -l /development/my-ruleset-project',
];
TestCore.flags = {
    location: core_1.Flags.string({ char: 'l', description: 'path where the project will be created' }),
    filter: core_1.Flags.string({ char: 'f', description: 'regex used to filter the examples that are going to be validated' }),
    debug: core_1.Flags.boolean({ char: 'd', description: 'generates debug output for the example being tested' }),
    skipLinting: core_1.Flags.boolean({ char: 's', description: 'does not lint the rulesets before running the tests' }),
};
TestCore.args = [];
//# sourceMappingURL=test.js.map