"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const trace_1 = require("../lib/commands/trace");
const trace_printer_1 = require("../lib/trace-printer");
const validate_1 = require("../lib/validate");
const path = require("node:path");
class TraceCore {
    constructor(fs, logger) {
        this.fs = fs;
        this.logger = logger;
    }
    async run(args, flags) {
        const location = flags.location ? path.resolve(flags.location) : path.resolve('.');
        const compact = flags.aggregate;
        const conformance = flags.negate;
        const traces = await new trace_1.default(location, args.id, args.ruleName, conformance, this.logger, this.fs).trace(compact);
        for (const l of trace_printer_1.TracePrinter.print(traces, conformance))
            this.logger.log(l);
        validate_1.default.singleton.terminate();
    }
}
exports.default = TraceCore;
TraceCore.description = 'shows a trace report of all the failing rule constraints for an example';
TraceCore.examples = [
    '<%= config.bin %> <%= command.id %> mandatory-tags negative1',
    '<%= config.bin %> <%= command.id %> mandatory-tags negative1 --agregate',
    '<%= config.bin %> <%= command.id %> mandatory-tags negative1 --negate',
];
TraceCore.flags = {
    location: core_1.Flags.string({ char: 'l', description: 'path where the project will be created' }),
    aggregate: core_1.Flags.boolean({ char: 'a', description: 'aggregate failures from multiple proofs for the same node', default: false }),
    negate: core_1.Flags.boolean({ char: 'n', description: 'checks the negation of the rule, useful to check rules that should not conform', default: false }),
};
TraceCore.args = [
    { name: 'ruleName', required: true, description: 'name of the rule where the example will be added' },
    { name: 'id', required: true, description: 'id of the example' },
];
//# sourceMappingURL=trace.js.map