"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const default_fs_1 = require("../fs/default-fs");
const fs_utils_1 = require("../fs/fs-utils");
// eslint-disable-next-line unicorn/import-style
const path = require("node:path");
class ExampleCreator {
    constructor(location, only, format, name, id, logger, fs) {
        this.only = only;
        this.format = format;
        this.logger = logger;
        this.name = name;
        this.id = id;
        this.location = location;
        this.fs = fs ? fs : new default_fs_1.default();
    }
    create() {
        if (this.format === 'project') {
            this.createProjectExample(this.fs, this.format, this.id, this.name);
        }
        else {
            if (this.only && (this.only !== 'positive' && this.only !== 'negative')) {
                this.logger.error('only positive|negative can be passed as arguments to only');
            }
            if (!Object.values(fs_utils_1.default.FORMATS).includes(this.format)) {
                this.logger.error(`Unknown example format ${this.format}, only oas|raml|graphql|asyncapi|swagger|gcl supported`);
            }
            const data = fs_utils_1.default.loadDefaultSpec(this.fs, this.format);
            if (this.only) {
                const isPositive = this.isPositive();
                if (fs_utils_1.default.existExampleData(this.fs, this.name, this.format, isPositive, this.id, this.location)) {
                    this.logger.error(`Rule example for id ${this.id} already exist`);
                }
                else {
                    const exampleFile = fs_utils_1.default.writeExampleData(this.fs, this.name, data, this.format, isPositive, this.id, this.location);
                    this.logger.log(`  - example file: ${exampleFile}`);
                }
            }
            else {
                if (fs_utils_1.default.existExampleData(this.fs, this.name, this.format, true, this.id, this.location)) {
                    this.logger.error(`Positive rule example for id ${this.id} already exist`);
                }
                else {
                    const exampleFile = fs_utils_1.default.writeExampleData(this.fs, this.name, data, this.format, true, this.id, this.location);
                    this.logger.log(`  - positive example file: ${exampleFile}`);
                }
                if (fs_utils_1.default.existExampleData(this.fs, this.name, this.format, false, this.id, this.location)) {
                    this.logger.error(`Negative rule example for id ${this.id} already exist`);
                }
                else {
                    const exampleFile = fs_utils_1.default.writeExampleData(this.fs, this.name, data, this.format, false, this.id, this.location);
                    this.logger.log(`  - negative example file: ${exampleFile}`);
                }
            }
        }
    }
    isPositive() {
        return this.only === 'positive';
    }
    createProjectExample(fs, defaultSpec, id, rulename) {
        let projectFolder = this.location;
        if (this.only) {
            if (this.only && (this.only !== 'positive' && this.only !== 'negative')) {
                this.logger.error('only positive|negative can be passed as arguments to only');
            }
            if (fs_utils_1.default.existFolders(fs, rulename, this.isPositive(), this.id, this.location)) {
                this.logger.error(`Rule example for id ${this.id} already exist`);
            }
            else {
                projectFolder = fs_utils_1.default.createExampleFolder(this.fs, rulename, this.isPositive(), this.id, this.location);
                this.folderProjectContent(this.fs, defaultSpec, projectFolder);
            }
        }
        else {
            // eslint-disable-next-line @typescript-eslint/ban-ts-comment
            // @ts-ignore
            if (fs_utils_1.default.existFolders(fs, rulename, true, this.id, projectFolder)) {
                this.logger.error(`Positive rule example for id ${this.id} already exist`);
            }
            else {
                const projectFolderPositive = fs_utils_1.default.createExampleFolder(this.fs, rulename, true, this.id, projectFolder);
                this.folderProjectContent(this.fs, defaultSpec, projectFolderPositive);
            }
            // eslint-disable-next-line @typescript-eslint/ban-ts-comment
            // @ts-ignore
            if (fs_utils_1.default.existFolders(fs, rulename, false, this.id, projectFolder)) {
                this.logger.error(`Negative rule example for id ${this.id} already exist`);
            }
            else {
                const projectFolderNegative = fs_utils_1.default.createExampleFolder(this.fs, rulename, false, this.id, projectFolder);
                this.folderProjectContent(this.fs, defaultSpec, projectFolderNegative);
            }
        }
    }
    folderProjectContent(fs, defaultSpec, projectFolder) {
        const exchangeJson = fs_utils_1.default.loadExchangeJson(fs, defaultSpec);
        const apiFile = fs_utils_1.default.loadDefaultSpec(fs, 'oas');
        const gclFile = fs_utils_1.default.loadDefaultSpec(fs, 'gcl');
        // define paths
        const exchangejsonPath = path.join(projectFolder, 'exchange.json');
        const apiFilePath = path.join(projectFolder, 'api.yaml');
        const gclFilePath = path.join(projectFolder, 'gcl.yaml');
        // write files
        fs.writeFileSync(exchangejsonPath, exchangeJson);
        fs.writeFileSync(apiFilePath, apiFile);
        fs.writeFileSync(gclFilePath, gclFile);
    }
}
exports.default = ExampleCreator;
//# sourceMappingURL=example-creator.js.map