"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs_utils_1 = require("../fs/fs-utils");
const spec_client_provider_1 = require("../spec/spec-client-provider");
class ModelGenerator {
    constructor(fs, logger) {
        this.fs = fs;
        this.logger = logger;
    }
    async generateModels(ruleDir, filter) {
        const allExamples = [...ruleDir.positive, ...ruleDir.negative];
        const filteredExamples = allExamples.filter(f => {
            return this.shouldValidate(filter, f);
        });
        if (filteredExamples.length > 0) {
            console.log(`\u001B[0m* Processing rule directory: ${ruleDir.path}`);
            return Promise.all(filteredExamples.map(async (f) => {
                const spectype = fs_utils_1.default.findSpecType(this.fs, f);
                if (spectype !== spec_client_provider_1.default.Spec.JSONLD) {
                    const client = spec_client_provider_1.default.buildClient(spectype, this.fs, f);
                    const framed = await client.generateGraph(f, true, false);
                    this.fs.writeFileSync(f + '.jsonld', framed);
                    this.logger.log(`\u001B[0m    - JSON-LD model: ${f}.jsonld`);
                }
            }));
        }
        return [];
    }
    shouldValidate(filter, name) {
        const re = new RegExp(filter);
        return re.test(name);
    }
    async generateModel(f, ruleDir) {
        console.log(`\u001B[0m* Processing rule example: ${f}`);
        const spectype = fs_utils_1.default.findSpecType(this.fs, f);
        if (spectype !== spec_client_provider_1.default.Spec.JSONLD) {
            const client = spec_client_provider_1.default.buildClient(spectype, this.fs, ruleDir.directory);
            const framed = await client.generateGraph(f, true, false);
            this.fs.writeFileSync(f + '.jsonld', framed);
            this.logger.log(`\u001B[0m    - JSON-LD model: ${f}.jsonld`);
        }
    }
    async dumpFiltered(location, filter = '.*') {
        const allPromises = (fs_utils_1.default.listRuleDirs(this.fs, this.logger, location).map(ruleDir => {
            return this.generateModels(ruleDir, filter);
        }));
        await Promise.all(allPromises);
    }
    async dumpSingle(location, name, id) {
        const ruleDir = fs_utils_1.default.listRuleDirs(this.fs, this.logger, location).find(rd => rd.ruleName === name || rd.path.endsWith(name));
        if (!ruleDir) {
            this.logger.error(`Cannot find rule named ${name} at directory ${location}`);
        }
        const example = ruleDir.findExample(id);
        if (!example) {
            this.logger.error(`Cannot find example ${id} for rule ${name}`);
        }
        await this.generateModel(example, ruleDir);
    }
}
exports.default = ModelGenerator;
//# sourceMappingURL=model-generator.js.map