"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs_utils_1 = require("../fs/fs-utils");
const example_creator_1 = require("./example-creator");
const ruleset_partitioner_1 = require("./ruleset-partitioner");
const profile_client_1 = require("../spec/aml/profile-client");
const config_loader_1 = require("../config-loader");
const default_fs_1 = require("../fs/default-fs");
class ProfileImporter {
    constructor(profilePath, workspacePath, shouldScaffoldExamples, logger, fs) {
        this.profilePath = profilePath;
        this.workspacePath = workspacePath;
        this.logger = logger;
        this.fs = fs !== null && fs !== void 0 ? fs : new default_fs_1.default();
        this.shouldScaffoldExamples = shouldScaffoldExamples;
    }
    import() {
        this.getRulesetInstance().then(instance => {
            const partitioner = new ruleset_partitioner_1.default(instance);
            return this.generateFiles(partitioner.run(), partitioner.name);
        });
    }
    getRulesetInstance() {
        const stats = this.fs.statSync(this.profilePath);
        if (stats.isDirectory()) {
            this.logger.error(`cant find profile to import in this path: ${this.profilePath}.`);
        }
        return profile_client_1.default.parseRuleset(this.profilePath, this.fs, this.logger.error).then(amfReport => amfReport.report.baseUnit);
    }
    async generateFiles(rules, name) {
        fs_utils_1.default.writeFile(this.fs, fs_utils_1.default.CONFIG_FILE, fs_utils_1.default.loadConfigFileTemplate(name, this.fs, 'oas'), this.workspacePath);
        const config = config_loader_1.default.fromFile(this.fs, this.workspacePath);
        this.fs.mkdirSync(this.workspacePath + '/' + fs_utils_1.default.RULES_DIR);
        for (const element of rules) {
            const content = profile_client_1.default.renderRuleset(element.instance);
            const ruleDir = fs_utils_1.default.mkRuleDir(this.fs, element.name, this.workspacePath);
            // eslint-disable-next-line no-await-in-loop
            fs_utils_1.default.writeProfile(this.fs, element.name, await content, config, this.workspacePath);
            if (this.shouldScaffoldExamples) {
                this.scaffoldExamplesForRule(ruleDir, element);
            }
        }
    }
    scaffoldExamplesForRule(ruleDir, element) {
        new example_creator_1.default(ruleDir, undefined, 'oas', undefined, element.name, this.logger, undefined).create();
    }
}
exports.default = ProfileImporter;
//# sourceMappingURL=profile-importer.js.map