"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs_utils_1 = require("../fs/fs-utils");
const default_fs_1 = require("../fs/default-fs");
const config_loader_1 = require("../config-loader");
const rule_creator_1 = require("./rule-creator");
class ProjectGenerator {
    constructor(name, prefix, logger, fs, defaultSpec, ruleNameProfile) {
        this.name = name;
        this.prefix = prefix;
        this.logger = logger;
        this.ruleNameProfile = ruleNameProfile;
        this.fs = fs ? fs : new default_fs_1.default();
        this.defaultSpec = defaultSpec ? defaultSpec : fs_utils_1.default.FORMATS.OAS;
    }
    async generate() {
        if (fs_utils_1.default.existConfigFile(this.fs, this.prefix)) {
            this.logger.error('Ruleset project already initialized');
        }
        // this.logger.log("Generating ruleset project skeleton for ruleset '" + this.name + "'")
        this.logger.log(`Generating ruleset project skeleton for ruleset '${this.name}'`);
        // create config file
        const configContent = fs_utils_1.default.loadConfigFileTemplate(this.name, this.fs, this.defaultSpec, this.ruleNameProfile);
        const configPath = fs_utils_1.default.writeFile(this.fs, fs_utils_1.default.CONFIG_FILE, configContent, this.prefix);
        this.logger.log(`  - project configuration file: ${configPath}`);
        const config = config_loader_1.default.fromFile(this.fs, this.prefix);
        const documentationFileName = config.rulesetConfig.documentation;
        const documentationPath = fs_utils_1.default.writeFile(this.fs, documentationFileName, fs_utils_1.default.loadDocFileTemplate(this.name, this.fs), this.prefix);
        this.logger.log(`  - documentation file: ${documentationPath}`);
        // create rules directory
        if (!fs_utils_1.default.existRulesDirectory(this.fs, this.prefix)) {
            const rulesPath = fs_utils_1.default.mkDir(this.fs, fs_utils_1.default.RULES_DIR, this.prefix);
            this.logger.log(`  - project rules directory: ${rulesPath}`);
        }
        // create sample rule
        const ruleName = 'sample-rule';
        this.logger.log(`  - creating sample rule: ${ruleName}`);
        const ruleCreator = new rule_creator_1.default(this.prefix, ruleName, undefined, undefined, this.logger, this.fs);
        ruleCreator.create();
    }
}
exports.default = ProjectGenerator;
//# sourceMappingURL=project-generator.js.map