"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const default_fs_1 = require("../fs/default-fs");
const fs_utils_1 = require("../fs/fs-utils");
const config_loader_1 = require("../config-loader");
const default_logger_1 = require("../logging/default-logger");
class Defaults {
}
Defaults.LEVEL = 'violation';
Defaults.MESSAGE = 'sample rule checking that the API has a description';
class RuleCreator {
    constructor(location, name, level, message, logger, fs) {
        this.location = location;
        this.name = name;
        this.level = level ? level : Defaults.LEVEL;
        this.message = message ? message : Defaults.MESSAGE;
        this.logger = logger ? logger : new default_logger_1.default();
        this.fs = fs ? fs : new default_fs_1.default();
        this.config = config_loader_1.default.fromFile(this.fs, this.location);
    }
    create() {
        if (this.level !== 'violation' && this.level !== 'warning' && this.level !== 'info') {
            this.logger.error(`Unknown severity level '${this.level}', only violation|warning|info supported`);
        }
        this.checkPresent(this.name, this.location);
        this.logger.log(`Generating rule directory skeleton for rule ${this.name} with severity ${this.level}`);
        const profileTemplate = fs_utils_1.default.readRuleTemplate(this.config.defaultSpec, this.fs);
        const profile = this.fillTemplate(profileTemplate);
        const dir = fs_utils_1.default.mkRuleDir(this.fs, this.name, this.location);
        this.logger.log(`  - rule directory: ${dir}`);
        const profileFile = fs_utils_1.default.writeProfile(this.fs, this.name, profile, this.config, this.location);
        this.logger.log(`  - rule profile: ${profileFile}`);
        this.logger.log('  - copying example files');
        fs_utils_1.default.copyRuleExamplesForSpec(this.config.defaultSpec, dir, this.fs);
    }
    checkPresent(ruleName, prefix) {
        if (fs_utils_1.default.existRuleDir(this.fs, ruleName, prefix)) {
            this.logger.error(`Rule ${ruleName} already created`);
        }
    }
    // different rules might have different templates. For now these will be the same
    fillTemplate(template) {
        return template
            .replace('{{profileName}}', this.config.name)
            .replace('{{ruleSeverity}}', this.level)
            .replace('{{ruleMessage}}', this.message)
            .replace(/{{ruleName}}/g, this.name);
    }
}
exports.default = RuleCreator;
//# sourceMappingURL=rule-creator.js.map