"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RulesetImporterResult = void 0;
const anypoint_apb_1 = require("anypoint-apb");
class RulesetPartitioner {
    constructor(profile) {
        const graph = profile.encodes.graph();
        this.validations = profile.encodes.getObjectByProperty(RulesetPartitioner.VALIDATIONS_PROPERTY_TERM);
        this.infoIndex = graph.scalarByProperty(RulesetPartitioner.INFO_PROPERTY_TERM).map(value => {
            return value.toString();
        });
        this.warningIndex = graph.scalarByProperty(RulesetPartitioner.WARNING_PROPERTY_TERM).map(value => {
            return value.toString();
        });
        this.name = graph.scalarByProperty(RulesetPartitioner.AMF_CORE_NAME).map(value => {
            return value.toString();
        })[0];
        this.profileMapping = profile.encodes.definedBy();
        this.dialectId = profile.definedBy().value();
        this.tags = graph.scalarByProperty(RulesetPartitioner.TAGS_TERM);
    }
    run() {
        return this.validations.map((v) => {
            return this.generateRulesetFrom(v);
        });
    }
    generateRulesetFrom(validation) {
        const validationName = validation.graph().scalarByProperty(RulesetPartitioner.AMF_CORE_NAME)[0];
        const encodes = new anypoint_apb_1.DialectDomainElement();
        encodes.withId('http://ruleset.plugin.aml#encodes');
        encodes.withDefinedby(this.profileMapping);
        encodes.withInstanceTypes([this.profileMapping.nodetypeMapping.value()]);
        encodes.withObjectCollectionProperty(RulesetPartitioner.VALIDATIONS_PROPERTY_TERM, [validation]);
        encodes.withLiteralProperty(RulesetPartitioner.AMF_CORE_NAME, this.name + '/' + validationName);
        if (this.infoIndex.includes(validationName))
            encodes.withLiteralProperty(RulesetPartitioner.INFO_PROPERTY_TERM, [validationName]);
        else if (this.warningIndex.includes(validationName))
            encodes.withLiteralProperty(RulesetPartitioner.WARNING_PROPERTY_TERM, [validationName]);
        else
            encodes.withLiteralProperty(RulesetPartitioner.VIOLATION_PROPERTY_TERM, [validationName]);
        const unit = new anypoint_apb_1.DialectInstance().withId('http://ruleset.plugin.aml#root').withEncodes(encodes).withDefinedBy(this.dialectId);
        return new RulesetImporterResult(unit, validationName);
    }
}
exports.default = RulesetPartitioner;
RulesetPartitioner.VALIDATIONS_PROPERTY_TERM = 'http://a.ml/vocabularies/amf-validation#validations';
RulesetPartitioner.WARNING_PROPERTY_TERM = 'http://a.ml/vocabularies/amf-validation#setSeverityWarning';
RulesetPartitioner.INFO_PROPERTY_TERM = 'http://a.ml/vocabularies/amf-validation#setSeverityInfo';
RulesetPartitioner.TAGS_TERM = 'http://a.ml/vocabularies/amf/core#tag';
RulesetPartitioner.VIOLATION_PROPERTY_TERM = 'http://a.ml/vocabularies/amf-validation#setSeverityViolation';
RulesetPartitioner.CORE_NAME = 'http://a.ml/vocabularies/core#name';
RulesetPartitioner.AMF_CORE_NAME = 'http://a.ml/vocabularies/amf/core#name';
class RulesetImporterResult {
    constructor(instance, name) {
        this.instance = instance;
        this.name = name;
    }
}
exports.RulesetImporterResult = RulesetImporterResult;
//# sourceMappingURL=ruleset-partitioner.js.map