"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const validator_report_1 = require("../validator-report");
const proof_builder_1 = require("../proof-builder");
const fs_utils_1 = require("../fs/fs-utils");
const default_fs_1 = require("../fs/default-fs");
class TraceRunner {
    constructor(location, id, ruleName, conformance, logger, fs) {
        this.location = location;
        this.id = id;
        this.ruleName = ruleName;
        this.conformance = conformance;
        this.logger = logger;
        this.fs = fs ? fs : new default_fs_1.default();
    }
    async trace(compact, lexicalInfo = false) {
        const ruleDir = fs_utils_1.default.listRuleDirs(this.fs, this.logger, this.location).find(ruledir => ruledir.ruleName === this.ruleName || ruledir.path.endsWith(this.ruleName));
        // eslint-disable-next-line no-eq-null,eqeqeq
        if (ruleDir == null) {
            this.logger.error(`Cannot find rule directory ${this.ruleName}`);
        }
        const example = ruleDir.findExample(this.id);
        if (!example) {
            this.logger.error(`Cannot find example ${this.id} for rule ${this.ruleName}`);
        }
        if (this.conformance)
            ruleDir.negateRule();
        const result = await ruleDir.validate(example, false, true, lexicalInfo);
        if (result.reportJSON) {
            const validatorReport = new validator_report_1.default(JSON.parse(result.reportJSON));
            const amfModel = ruleDir.enrichedAmfModel();
            const traces = new proof_builder_1.ProofBuilder(validatorReport, amfModel, result.normalized).build(compact);
            if (traces.length === 0) {
                this.conformance ? this.logger.log('No successful proofs were found') : this.logger.log('No failed validations were found');
            }
            return traces;
        }
        for (const l of result.log)
            this.logger.log(l);
        this.logger.error('Error validating example');
        return [];
    }
}
exports.default = TraceRunner;
//# sourceMappingURL=trace.js.map