"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("node:fs");
const path = require("node:path");
/**
 * File manipulation functions over the ruleset project
 */
// eslint-disable-next-line unicorn/no-static-only-class
class DefaultFs {
    mkdirSync(path) {
        return fs.mkdirSync(path);
    }
    cpSync(path, target, opts) {
        return fs.cpSync(path, target, opts);
    }
    statSync(dir) {
        return fs.statSync(dir);
    }
    readdirSync(file) {
        return fs.readdirSync(file);
    }
    existsSync(file) {
        return fs.existsSync(file);
    }
    listDirectory(dir) {
        let acc = new Array();
        const results = fs.readdirSync(dir);
        for (const result of results) {
            const nextfilePath = path.join(dir, result);
            if (fs.statSync(nextfilePath).isDirectory()) {
                if (this.existsSync(path.join(nextfilePath, 'exchange.json'))) {
                    acc.push(nextfilePath);
                }
                else {
                    const nested = this.listDirectory(nextfilePath);
                    acc = [...acc, ...nested];
                }
            }
            else {
                acc.push(nextfilePath);
            }
        }
        return acc;
    }
    loadFile(f) {
        return fs.readFileSync(f, 'utf8').toString();
    }
    writeFileSync(file, data) {
        return fs.writeFileSync(file, data);
    }
    readFileSync(file) {
        return fs.readFileSync(file, 'utf-8');
    }
}
exports.default = DefaultFs;
//# sourceMappingURL=default-fs.js.map