"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const anypoint_apb_1 = require("anypoint-apb");
function getAmlConfig(rl) {
    return anypoint_apb_1.AMLConfiguration.predefined().withResourceLoader(rl);
}
class AMLParser {
    static async parseWithDialect(dialectUrl, url, rl) {
        const dialect = await AMLParser.parseDialect(dialectUrl, rl);
        return AMLParser.parseInstance(dialect, rl, url);
    }
    static async parseDialect(dialectUrl, rl) {
        const amlConfig = getAmlConfig(rl);
        const client = amlConfig.baseUnitClient();
        const parseResult = await client.parseDialect('file://' + dialectUrl);
        if (!parseResult.conforms) {
            throw new Error('Invalid bundled dialect for Rulesets');
        }
        return parseResult.dialect;
    }
    static async parseInstance(dialect, rl, rulesetUrl) {
        const amlConfig = getAmlConfig(rl);
        const client = await amlConfig.withDialect(dialect).baseUnitClient();
        return client.parseDialectInstance('file://' + rulesetUrl);
    }
    static renderInstance(dialect, dialectInstance) {
        return anypoint_apb_1.AMLConfiguration.predefined().withDialect(dialect).baseUnitClient().render(dialectInstance);
    }
}
exports.default = AMLParser;
//# sourceMappingURL=aml-parser.js.map