"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
// eslint-disable-next-line @typescript-eslint/ban-ts-comment
// @ts-ignore
const anypoint_apb_1 = require("anypoint-apb");
const jsonld = require('jsonld');
class AMFAPIGenerator {
    static async generate(baseUnit, framed = false, sourceMaps = false) {
        let renderOpts = new anypoint_apb_1.RenderOptions().withSourceMaps().withCompactUris().withSourceInformation();
        if (!sourceMaps) {
            renderOpts = renderOpts.withGovernanceMode;
        }
        const amfConfig = anypoint_apb_1.AMFGraphConfiguration.predefined().withRenderOptions(renderOpts);
        const model = anypoint_apb_1.AMFRenderer.render(baseUnit, amfConfig);
        if (framed) {
            return this.frame(model);
        }
        return model;
    }
    static async frame(model) {
        const json = JSON.parse(model);
        const oneId = json['@graph'][0]['@id'];
        const base = oneId.split('#')[0] + '#';
        const context = {
            '@context': {
                '@base': base,
                data: 'http://a.ml/vocabularies/data#',
                shacl: 'http://www.w3.org/ns/shacl#',
                shapes: 'http://a.ml/vocabularies/shapes#',
                doc: 'http://a.ml/vocabularies/document#',
                meta: 'http://a.ml/vocabularies/meta#',
                apiContract: 'http://a.ml/vocabularies/apiContract#',
                core: 'http://a.ml/vocabularies/core#',
                xsd: 'http://www.w3.org/2001/XMLSchema#',
                rdfs: 'http://www.w3.org/2000/01/rdf-schema',
                rdf: 'http://www.w3.org/1999/02/22-rdf-syntax-ns#',
                security: 'http://a.ml/vocabularies/security#',
                sourcemaps: 'http://a.ml/vocabularies/document-source-maps#',
            },
        };
        const framed = await jsonld.compact(json, context);
        return JSON.stringify(this.connect(framed), null, 2);
    }
    static connect(model) {
        const acc = {};
        const counts = {};
        const toProcess = new Array();
        for (const node of model['@graph'] || []) {
            const id = node['@id'];
            acc[id] = node;
            counts[id] = 0;
            if (node['doc:root'] === true) {
                toProcess.unshift(node);
            }
            else
                toProcess.push(node);
        }
        for (const node of toProcess) {
            // eslint-disable-next-line guard-for-in
            for (const p in node) {
                if (this.isLink(node[p])) {
                    node[p] = this.doLink(node[p], acc, counts);
                }
                if (typeof node[p] === 'object' && node[p].constructor.name === 'Array') {
                    const accVs = new Array();
                    for (const v of node[p]) {
                        if (this.isLink(v)) {
                            accVs.push(this.doLink(v, acc, counts));
                        }
                        else {
                            accVs.push(v);
                        }
                    }
                    node[p] = accVs;
                }
            }
        }
        const filtered = new Array();
        for (const node of model['@graph'] || []) {
            const id = node['@id'];
            if (counts[id] === 0) {
                filtered.push(node);
            }
        }
        model['@graph'] = filtered;
        return model;
    }
    static doLink(node, acc, counts) {
        const link = node['@id'];
        const linked = acc[link];
        if (linked) {
            counts[link]++;
            if (counts[link] < 2) {
                return linked;
            }
        }
        return node;
    }
    static isLink(node) {
        return typeof node === 'object' && node['@id'];
    }
}
exports.default = AMFAPIGenerator;
//# sourceMappingURL=generate.js.map