"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.GCLSpecClient = void 0;
const anypoint_apb_1 = require("anypoint-apb");
const spec_client_1 = require("./spec-client");
const fs_utils_1 = require("../fs/fs-utils");
const default_fs_1 = require("../fs/default-fs");
const render_options_builder_1 = require("./amf-core/render-options-builder");
const errors_1 = require("@oclif/core/lib/errors");
class GCLSpecClient extends spec_client_1.SpecClient {
    render(element, framed, sourceMaps) {
        const renderOptions = new render_options_builder_1.default().withSourceMaps(sourceMaps).build();
        // eslint-disable-next-line new-cap
        const client = anypoint_apb_1.JsonLDSchemaConfiguration.JsonLDSchema().withRenderOptions(renderOptions).baseUnitClient();
        return new Promise(function (resolve) {
            resolve(client.render(element));
        });
    }
    parse(url) {
        const elementParsed = this.parseElement(url);
        return elementParsed.then(element => this.createDocument(element));
    }
    createDocument(elements) {
        const jsonLDInstance = new anypoint_apb_1.JsonLDInstanceDocument();
        const withId = jsonLDInstance.withId('amf://#1');
        return withId.withEncodes(elements);
    }
    parseElement(url) {
        const instanceUrl = new anypoint_apb_1.Instance(url);
        return anypoint_apb_1.APIInstanceClient.build(instanceUrl, [this.getRL()]).then(buildResult => {
            // TODO: This is ignoring possible errors with the parsing (buildResult.results). Some of these error could end in an empty result
            const instance = buildResult.result();
            return instance.encodes;
        });
    }
    getRL() {
        return this.rl ? this.rl : fs_utils_1.default.fsToResourceLoader(new default_fs_1.default(), undefined, errors_1.error);
    }
}
exports.GCLSpecClient = GCLSpecClient;
//# sourceMappingURL=gcl-spec-client.js.map