"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const amf = require("anypoint-apb");
const amf_spec_client_1 = require("./amf-spec-client");
const gcl_spec_client_1 = require("./gcl-spec-client");
const fs_utils_1 = require("../fs/fs-utils");
const project_client_1 = require("./project-client");
class SpecClientProvider {
    static buildClient(spec, fs, base) {
        return SpecClientProvider.getClient(spec).withResourceLoader(fs_utils_1.default.fsToResourceLoader(fs, base));
    }
    static getClient(spec) {
        switch (spec) {
            case (SpecClientProvider.Spec.OAS): {
                // eslint-disable-next-line new-cap
                return new amf_spec_client_1.AMFSpecClient(amf.OASConfiguration.OAS30());
            }
            case (SpecClientProvider.Spec.SWAGGER): {
                // eslint-disable-next-line new-cap
                return new amf_spec_client_1.AMFSpecClient(amf.OASConfiguration.OAS20());
            }
            case (SpecClientProvider.Spec.RAML): {
                // eslint-disable-next-line new-cap
                return new amf_spec_client_1.AMFSpecClient(amf.RAMLConfiguration.RAML10());
            }
            case (SpecClientProvider.Spec.ASYNCAPI): {
                // eslint-disable-next-line new-cap
                return new amf_spec_client_1.AMFSpecClient(amf.AsyncAPIConfiguration.Async20());
            }
            case (SpecClientProvider.Spec.GRAPHQL): {
                // eslint-disable-next-line new-cap
                return new amf_spec_client_1.AMFSpecClient(amf.GraphQLConfiguration.GraphQL());
            }
            case SpecClientProvider.Spec.GRPC: {
                // eslint-disable-next-line new-cap
                return new amf_spec_client_1.AMFSpecClient(amf.GRPCConfiguration.GRPC());
            }
            case (SpecClientProvider.Spec.GCL): {
                return new gcl_spec_client_1.GCLSpecClient();
            }
            case (SpecClientProvider.Spec.PROJECT): {
                return new project_client_1.ProjectClient();
            }
            default:
                throw new Error('Unknown configuration ' + spec);
        }
    }
}
exports.default = SpecClientProvider;
SpecClientProvider.Spec = {
    OAS: 'oas',
    SWAGGER: 'swagger',
    RAML: 'raml',
    ASYNCAPI: 'asyncapi',
    GRAPHQL: 'graphql',
    GRPC: 'grpc',
    JSONLD: 'jsonld',
    GCL: 'gcl',
    PROJECT: 'project',
};
//# sourceMappingURL=spec-client-provider.js.map