"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Link = void 0;
const colors_1 = require("../colors");
class Link {
    constructor(path, successful, failed, cardinality, component, negated, location) {
        this._path = path;
        this.successful = successful;
        this.failed = failed;
        this.negated = negated;
        this.cardinality = cardinality;
        this.location = location;
        this.nodes = [];
        this.component = component;
    }
    get path() {
        return this._path;
    }
    merge(other) {
        const acc = {};
        for (const n of this.nodes) {
            acc[n.name] = n;
        }
        for (const n of other.nodes) {
            const present = acc[n.name];
            if (present) {
                present.merge(n);
                present.compact();
            }
            else {
                acc[n.name] = n;
            }
        }
        this.nodes = Object.values(acc);
    }
    compact() {
        const acc = {};
        for (const n of this.nodes) {
            const present = acc[n.name];
            if (present) {
                present.merge(n);
                present.compact();
            }
            else {
                n.compact();
                acc[n.name] = n;
            }
        }
        this.nodes = Object.values(acc);
    }
    print(conformance, indentation, isLastLink = false) {
        const acc = [];
        const existAcc = [];
        const linkIndentation = isLastLink ? `${indentation}└──` : `${indentation}├──`;
        let nestedIndentation = isLastLink ? `${indentation}` : `${indentation}│`;
        let existential = '';
        let toPrint = '';
        switch (this.component) {
            case 'nested':
                toPrint = `(link) ${this.path}`;
                acc.push(`${linkIndentation}${colors_1.default.yellow(toPrint)}`);
                break;
            case 'atLeast':
                toPrint = `(link) ${this.path}`;
                existAcc.push(`${linkIndentation}${colors_1.default.yellow(toPrint)}`);
                nestedIndentation += '     ';
                if (this.negated) {
                    existential = `(check) at least ${(this.successful + this.failed) - (this.cardinality - 1)} failed nodes expected but found ${this.successful} successful and the following ${this.failed} failed nodes:`;
                }
                else {
                    existential = `(check) at least ${this.cardinality} successful nodes expected but found only ${this.successful} successful nodes and the following ${this.failed} failed nodes:`;
                }
                existAcc.push(`${nestedIndentation}└──${colors_1.default.red(existential)}`);
                acc.push(existAcc.join(`\n${nestedIndentation}│\n`));
                break;
            case 'atMost':
                toPrint = `(link) ${this.path}`;
                existAcc.push(`${linkIndentation}${colors_1.default.yellow(toPrint)}`);
                nestedIndentation += '     ';
                if (this.negated) {
                    existential = `(check) at most ${(this.successful + this.failed) - (this.cardinality + 1)} failed nodes expected but found only ${this.successful} successful nodes and the following ${this.failed} failed nodes:`;
                }
                else {
                    existential = `(check) at most ${this.cardinality} successful nodes expected but found only ${this.successful} successful nodes and the following ${this.failed} failed nodes:`;
                }
                existAcc.push(`${nestedIndentation}└──${colors_1.default.red(existential)}`);
                acc.push(existAcc.join(`\n${nestedIndentation}│\n`));
                break;
            default:
                throw new Error('Unknown link component ' + this.component);
        }
        const lastNode = this.nodes.pop();
        for (const n of this.nodes) {
            acc.push(n.print(conformance, `${nestedIndentation}     `));
        }
        if (lastNode) {
            acc.push(lastNode.print(conformance, `${nestedIndentation}     `, true));
        }
        return acc.join(`\n${nestedIndentation}     │\n`);
    }
}
exports.Link = Link;
//# sourceMappingURL=link.js.map