"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Node = void 0;
const colors_1 = require("../colors");
class Node {
    constructor(name, type, location) {
        this._name = name;
        this.type = type;
        this.location = location;
        this.links = [];
        this.properties = [];
    }
    get name() {
        return this._name;
    }
    merge(other) {
        const accProps = {};
        for (const p of this.properties) {
            accProps[p.path] = p;
        }
        for (const p of other.properties) {
            const present = accProps[p.path];
            if (present) {
                present.merge(p);
            }
            else {
                accProps[p.path] = p;
            }
        }
        this.properties = Object.values(accProps);
        const accLinks = {};
        for (const p of this.links) {
            accLinks[p.path] = p;
        }
        for (const p of other.links) {
            const present = accLinks[p.path];
            if (present) {
                present.merge(p);
            }
            else {
                accLinks[p.path] = p;
            }
        }
        this.links = Object.values(accLinks);
    }
    compact() {
        const accProps = {};
        for (const p of this.properties) {
            const present = accProps[p.path];
            if (present) {
                present.merge(p);
            }
            else {
                accProps[p.path] = p;
            }
        }
        this.properties = Object.values(accProps);
        const accLinks = {};
        for (const p of this.links) {
            const present = accLinks[p.path];
            if (present) {
                present.merge(p);
                present.compact();
            }
            else {
                p.compact();
                accLinks[p.path] = p;
            }
        }
        this.links = Object.values(accLinks);
    }
    print(conformance, indentation, isLastNode = false) {
        const acc = [];
        const nodeIdentation = isLastNode ? `${indentation}└──` : `${indentation}├──`;
        const nestedIndentation = isLastNode ? `${indentation}` : `${indentation}│`;
        const toPrint = `(Node) ${this.type} ${this.name}`;
        acc.push(`${nodeIdentation}${colors_1.default.cyan(toPrint)}`);
        const lastProperty = this.properties.pop();
        const lastLink = this.links.pop();
        for (const p of this.properties) {
            acc.push(p.print(conformance, `${nestedIndentation}    `));
        }
        if (lastLink) {
            if (lastProperty)
                acc.push(lastProperty.print(conformance, `${nestedIndentation}    `));
        }
        else if (lastProperty)
            acc.push(lastProperty.print(conformance, `${nestedIndentation}    `, true));
        for (const l of this.links) {
            acc.push(l.print(conformance, `${nestedIndentation}    `));
        }
        if (lastLink) {
            acc.push(lastLink.print(conformance, `${nestedIndentation}    `, true));
        }
        return acc.join(`\n${nestedIndentation}    │\n`);
    }
}
exports.Node = Node;
//# sourceMappingURL=node.js.map