"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Proof = void 0;
class Proof {
    constructor(validation, level, message, location) {
        this._validation = validation;
        this.level = level;
        this.message = message;
        this.location = location;
        this.nodes = [];
    }
    get validation() {
        return this._validation;
    }
    compact() {
        const acc = {};
        for (const n of this.nodes) {
            const present = acc[n.name];
            if (present) {
                present.merge(n);
            }
            else {
                n.compact();
                acc[n.name] = n;
            }
        }
        this.nodes = Object.values(acc);
    }
    merge(other) {
        const acc = {};
        for (const n of this.nodes) {
            acc[n.name] = n;
        }
        for (const n of other.nodes) {
            const present = acc[n.name];
            if (present) {
                present.merge(n);
                present.compact();
            }
            else {
                acc[n.name] = n;
            }
        }
        this.nodes = Object.values(acc);
        return this;
    }
    print(conformance) {
        const acc = [];
        acc.push(`[${this.level}] ${this.validation}: ${this.message}`);
        const lastNode = this.nodes.pop();
        for (const n of this.nodes) {
            acc.push(n.print(conformance, '  '));
        }
        if (lastNode) {
            acc.push(lastNode.print(conformance, '  ', true));
        }
        return acc.join('\n  │\n');
    }
}
exports.Proof = Proof;
//# sourceMappingURL=proof.js.map