"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Property = void 0;
const colors_1 = require("../colors");
class Property {
    constructor(path, location) {
        this._path = path;
        this.location = location;
        this.constraints = [];
    }
    get path() {
        return this._path;
    }
    merge(other) {
        const acc = {};
        for (const c of this.constraints) {
            acc[c.invocation] = c;
        }
        for (const c of other.constraints) {
            if (!acc[c.invocation]) {
                acc[c.invocation] = c;
            }
        }
        this.constraints = Object.values(acc);
    }
    print(conformance, indentation, isLastProperty = false) {
        const acc = [];
        const propIdentation = isLastProperty ? `${indentation}└──` : `${indentation}├──`;
        const nestedIndentation = isLastProperty ? `${indentation}` : `${indentation}│`;
        const toPrint = `(prop) ${this.path}`;
        acc.push(`${propIdentation}${colors_1.default.magenta(toPrint)}`);
        const lastConstraint = this.constraints.pop();
        for (const c of this.constraints) {
            acc.push(c.print(conformance, `${nestedIndentation}    `));
        }
        if (lastConstraint)
            acc.push(lastConstraint.print(conformance, `${nestedIndentation}    `, true));
        return acc.join(`\n${nestedIndentation}    │\n`);
    }
}
exports.Property = Property;
//# sourceMappingURL=property.js.map